@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 2001-2018 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 from Mailman import mm_cfg
 from Mailman.i18n import _
@@ -142,6 +142,15 @@ class Bounce(GUIBase):
              <a href="?VARHELP=autoreply/autoresponse_admin_text">autoresponse
              message</a> for email to the -owner and -admin address.""")),
 
+            ('bounce_notify_owner_on_bounce_increment', mm_cfg.Toggle,
+             (_('No'), _('Yes')), 0,
+             _("""Should Mailman notify you, the list owner, when bounces
+             cause a member's bounce score to be incremented?"""),
+             _("""Setting this value to <em>Yes</em> will cause Mailman to
+             send a notice including a copy of the bounce message to the list
+             owners whenever a bounce increments a member's bounce score but
+             doesn't cause a disable or a probe to be sent.""")),
+
             ('bounce_notify_owner_on_disable', mm_cfg.Toggle,
              (_('No'), _('Yes')), 0,
              _("""Should Mailman notify you, the list owner, when bounces
