@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.7
+#!/2022Q2/bin/python2.7
 
 from __future__ import nested_scopes
 
@@ -12,6 +12,10 @@ import cPickle as pickle
 from cStringIO import StringIO
 from string import lowercase
 
+# Work around for some misguided Python packages that add iso-8859-1
+# accented characters to string.lowercase.
+lowercase = lowercase[:26]
+
 __version__ = '0.09 (Mailman edition)'
 VERSION = __version__
 CACHESIZE = 100    # Number of slots in the cache
