@@ -54,7 +54,7 @@ No = no = Off = off = False
 # disable Mailman's logo footer altogther, hack
 # Mailman/htmlformat.py:MailmanLogo(), which also contains the hardcoded links
 # and image names.
-IMAGE_LOGOS = '/icons/'
+IMAGE_LOGOS = '/mailman-icons/'
 
 # The name of the Mailman favicon
 SHORTCUT_ICON = 'mm-icon.png'
@@ -64,6 +64,11 @@ MAILMAN_URL = 'http://www.gnu.org/software/mailman/index.html'
 #MAILMAN_URL = 'http://www.list.org/'
 #MAILMAN_URL = 'http://mailman.sf.net/'
 
+# Details of third image
+IMAGE3_URL = 'http://www.gnu.org/'
+IMAGE3_IMG = 'gnu-head-tiny.jpg'
+IMAGE3_ALT = 'Gnu\'s Not Unix'
+
 # Mailman needs to know about (at least) two fully-qualified domain names
 # (fqdn); 1) the hostname used in your urls, and 2) the hostname used in email
 # addresses for your domain.  For example, if people visit your Mailman system
@@ -83,8 +88,8 @@ MAILMAN_URL = 'http://www.gnu.org/software/mailman/index.html'
 #     add_virtualhost(DEFAULT_URL_HOST, DEFAULT_EMAIL_HOST)
 #
 # because otherwise the default mappings won't be correct.
-DEFAULT_EMAIL_HOST = 'localhost.my.domain'
-DEFAULT_URL_HOST = 'localhost.my.domain'
+DEFAULT_EMAIL_HOST = 'localhost'
+DEFAULT_URL_HOST = 'localhost'
 DEFAULT_URL_PATTERN = 'http://%s/mailman/'
 
 # DEFAULT_HOST_NAME has been replaced with DEFAULT_EMAIL_HOST, however some
@@ -612,7 +617,7 @@ SMTPPORT = 0                                      # default from smtplib
 
 # Command for direct command pipe delivery to sendmail compatible program,
 # when DELIVERY_MODULE is 'Sendmail'.
-SENDMAIL_CMD = '/usr/sbin/sendmail'
+SENDMAIL_CMD = '/usr/lib/sendmail'
 
 # SMTP authentication for DELIVERY_MODULE = 'SMTPDirect'.  To enable SASL
 # authentication for SMTPDirect, set SMTP_AUTH = Yes and provide appropriate
@@ -841,7 +846,10 @@ VERP_PROBES = No
 
 # A perfect opportunity for doing VERP is the password reminders, which are
 # already addressed individually to each recipient.  Set this to Yes to enable
-# VERPs on all password reminders.
+# VERPs on all password reminders.  However, because password reminders are
+# sent from the site list and site list bounces aren't processed but are just
+# forwarded to the site list admins, this isn't too useful.  See comments at
+# lines 70-84 of Mailman/Queue/BounceRunner.py for why we don't process them.
 VERP_PASSWORD_REMINDERS = No
 
 # Another good opportunity is when regular delivery is personalized.  Here
@@ -1640,21 +1648,21 @@ PENDINGDB_LOCK_DEBUGGING = Off
 # These directories are used to find various important files in the Mailman
 # installation.  PREFIX and EXEC_PREFIX are set by configure and should point
 # to the installation directory of the Mailman package.
-PYTHON          = '/usr/local/bin/python2.7'
-PREFIX          = '/usr/local/lib/mailman'
+PYTHON          = '/2022Q2/bin/python2.7'
+PREFIX          = '/2022Q2/lib/mailman'
 EXEC_PREFIX     = '${prefix}'
-VAR_PREFIX      = '/var/spool/mailman'
+VAR_PREFIX      = '/2022Q2/var/db/mailman'
 
 # Work around a bogus autoconf 2.12 bug
 if EXEC_PREFIX == '${prefix}':
     EXEC_PREFIX = PREFIX
 
 # CGI extension, change using configure script
-CGIEXT = ''
+CGIEXT = '.cgi'
 
 # Group id that group-owns the Mailman installation
-MAILMAN_USER = ''
-MAILMAN_GROUP = ''
+MAILMAN_USER = 'mailman'
+MAILMAN_GROUP = 'mailman'
 
 # Enumeration for Mailman cgi widget types
 Toggle      = 1
