@@ -7,7 +7,7 @@
  */
 
 static char *version =
-"$Id: _japanese_codecs.c,v 1.10 2002/09/24 06:57:27 kajiyama Exp $";
+"$Id: _japanese_codecs.c,v 1.12 2003/11/29 23:19:15 kajiyama Exp $";
 
 #include "Python.h"
 
@@ -138,7 +138,7 @@ encode_euc_jp(const Py_UNICODE *s, int size, const char *errors)
   if (errtype == error_undef)
     return NULL;
 
-  v = PyString_FromStringAndSize(NULL, size * 2);
+  v = PyString_FromStringAndSize(NULL, size * 3);
   if (v == NULL)
     return NULL;
   if (size == 0)
@@ -494,6 +494,10 @@ decode_shift_jis(unsigned char *s, int size, const char *errors)
     }
     /* JIS X 0208 */
     else if (s + 1 < end &&
+             ((0x81 <= *s && *s <= 0x9f) ||
+              (0xe0 <= *s && *s <= 0xfc)) &&
+             ((0x40 <= *(s+1) && *(s+1) <= 0x7e) ||
+              (0x80 <= *(s+1) && *(s+1) <= 0xfc)) &&
              lookup_jis_map(jisx0208_jis_map, SJIS2EUC(*s, *(s+1)), p)) {
       p++;
       s += 2;
@@ -705,6 +709,10 @@ decode_ms932(unsigned char *s, int size, const char *errors)
     }
     /* JIS X 0208 */
     else if (s + 1 < end &&
+             ((0x81 <= *s && *s <= 0x9f) ||
+              (0xe0 <= *s && *s <= 0xfc)) &&
+             ((0x40 <= *(s+1) && *(s+1) <= 0x7e) ||
+              (0x80 <= *(s+1) && *(s+1) <= 0xfc)) &&
              lookup_jis_map(jisx0208_jis_map, SJIS2EUC(*s, *(s+1)), p)) {
       p++;
       s += 2;
