@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2014 by the Free Software Foundation, Inc.
+# Copyright (C) 2001-2018 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -614,8 +614,11 @@ From: aperson@dom.ain
         msgdata = {}
         CookHeaders.process(mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'aperson@dom.ain, _xtest@dom.ain')
+            '_xtest@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
         eq(msg.get_all('reply-to'), None)
+        eq(msg.get_all('cc'), None)
 
     def test_reply_to_list_with_strip(self):
         eq = self.assertEqual
@@ -647,8 +650,12 @@ Reply-To: bperson@dom.ain
         msgdata = {}
         CookHeaders.process(mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'aperson@dom.ain, _xtest@dom.ain')
+            '_xtest@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
         eq(msg.get_all('reply-to'), ['bperson@dom.ain'])
+        eq(msg.get_all('cc'), None)
+
 
     def test_reply_to_explicit(self):
         eq = self.assertEqual
@@ -678,8 +685,11 @@ From: aperson@dom.ain
         msgdata = {}
         CookHeaders.process(mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'mlist@dom.ain, aperson@dom.ain')
+            'mlist@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
         eq(msg.get_all('reply-to'), None)
+        eq(msg.get_all('cc'), None)
 
     def test_reply_to_explicit_with_strip(self):
         eq = self.assertEqual
@@ -715,8 +725,11 @@ Reply-To: bperson@dom.ain
 
         CookHeaders.process(self._mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'mlist@dom.ain, aperson@dom.ain')
+            'mlist@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
         eq(msg.get_all('reply-to'), ['bperson@dom.ain'])
+        eq(msg.get_all('cc'), None)
 
     def test_reply_to_extends_to_list(self):
         eq = self.assertEqual
@@ -750,7 +763,11 @@ Reply-To: bperson@dom.ain
 
         CookHeaders.process(mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'bperson@dom.ain, aperson@dom.ain, _xtest@dom.ain')
+            'bperson@dom.ain, _xtest@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
+        eq(msg.get_all('reply-to'), ['bperson@dom.ain'])
+        eq(msg.get_all('cc'), None)
 
     def test_reply_to_extends_to_explicit(self):
         eq = self.assertEqual
@@ -784,7 +801,11 @@ Reply-To: bperson@dom.ain
         msgdata = {}
         CookHeaders.process(mlist, msg, msgdata)
         eq(msgdata['add_header']['Reply-To'],
-            'mlist@dom.ain, bperson@dom.ain, aperson@dom.ain')
+            'mlist@dom.ain, bperson@dom.ain')
+        eq(msgdata['add_header']['Cc'],
+            'aperson@dom.ain')
+        eq(msg.get_all('reply-to'), ['bperson@dom.ain'])
+        eq(msg.get_all('cc'), None)
 
     def test_list_headers_nolist(self):
         eq = self.assertEqual
@@ -817,10 +838,10 @@ From: aperson@dom.ain
         eq(msg['list-help'], '<mailto:_xtest-request@dom.ain?subject=help>')
         eq(msg['list-unsubscribe'],
            '<http://www.dom.ain/mailman/options/_xtest>,'
-           '\n\t<mailto:_xtest-request@dom.ain?subject=unsubscribe>')
+           '\n <mailto:_xtest-request@dom.ain?subject=unsubscribe>')
         eq(msg['list-subscribe'],
            '<http://www.dom.ain/mailman/listinfo/_xtest>,'
-           '\n\t<mailto:_xtest-request@dom.ain?subject=subscribe>')
+           '\n <mailto:_xtest-request@dom.ain?subject=subscribe>')
         eq(msg['list-post'], '<mailto:_xtest@dom.ain>')
         eq(msg['list-archive'], '<http://www.dom.ain/pipermail/_xtest/>')
 
@@ -837,10 +858,10 @@ From: aperson@dom.ain
         eq(msg['list-help'], '<mailto:_xtest-request@dom.ain?subject=help>')
         eq(msg['list-unsubscribe'],
            '<http://www.dom.ain/mailman/options/_xtest>,'
-           '\n\t<mailto:_xtest-request@dom.ain?subject=unsubscribe>')
+           '\n <mailto:_xtest-request@dom.ain?subject=unsubscribe>')
         eq(msg['list-subscribe'],
            '<http://www.dom.ain/mailman/listinfo/_xtest>,'
-           '\n\t<mailto:_xtest-request@dom.ain?subject=subscribe>')
+           '\n <mailto:_xtest-request@dom.ain?subject=subscribe>')
         eq(msg['list-post'], '<mailto:_xtest@dom.ain>')
 
 
@@ -865,7 +886,8 @@ Here is a message.
         self.assertEqual(msg.get_payload(), """\
 header
 Here is a message.
-footer""")
+footer
+""")
 
     def test_no_multipart_template(self):
         mlist = self._mlist
@@ -881,7 +903,8 @@ Here is a message.
         self.assertEqual(msg.get_payload(), """\
 XTest header
 Here is a message.
-XTest footer""")
+XTest footer
+""")
 
     def test_no_multipart_type_error(self):
         mlist = self._mlist
@@ -897,7 +920,8 @@ Here is a message.
         self.assertEqual(msg.get_payload(), """\
 %(real_name) header
 Here is a message.
-%(real_name) footer""")
+%(real_name) footer
+""")
 
     def test_no_multipart_value_error(self):
         mlist = self._mlist
@@ -914,7 +938,8 @@ Here is a message.
         self.assertEqual(msg.get_payload(), """\
 %(real_name)p header
 Here is a message.
-%(real_name)p footer""")
+%(real_name)p footer
+""")
 
     def test_no_multipart_missing_key(self):
         mlist = self._mlist
@@ -929,7 +954,8 @@ Here is a message.
         self.assertEqual(msg.get_payload(), """\
 %(spooge)s header
 Here is a message.
-%(spooge)s footer""")
+%(spooge)s footer
+""")
 
     def test_multipart(self):
         eq = self.ndiffAssertEqual
@@ -963,6 +989,7 @@ Content-Transfer-Encoding: 7bit
 Content-Disposition: inline
 
 header
+
 --BOUNDARY
 From: aperson@dom.ain
 
@@ -980,7 +1007,9 @@ Content-Transfer-Encoding: 7bit
 Content-Disposition: inline
 
 footer
---BOUNDARY--""")
+
+--BOUNDARY--
+""")
 
     def test_image(self):
         eq = self.assertEqual
@@ -1749,7 +1778,8 @@ class TestReplybot(TestBase):
 class TestSpamDetect(TestBase):
     def test_short_circuit(self):
         msgdata = {'approved': 1}
-        rtn = SpamDetect.process(self._mlist, None, msgdata)
+        msg = email.message_from_string('', Message.Message)
+        rtn = SpamDetect.process(self._mlist, msg, msgdata)
         # Not really a great test, but there's little else to assert
         self.assertEqual(rtn, None)
 
@@ -1758,12 +1788,12 @@ class TestSpamDetect(TestBase):
 From: aperson@dom.ain
 
 A message.
-""")
+""", Message.Message)
         msg2 = email.message_from_string("""\
 To: xlist@dom.ain
 
 A message.
-""")
+""", Message.Message)
         spammers = mm_cfg.KNOWN_SPAMMERS[:]
         try:
             mm_cfg.KNOWN_SPAMMERS.append(('from', '.?person'))
